Coverage report

File | function | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/mafw_tools/__init__.py | (no function) | 0 | 0 | 0 | 0 | 0 | 100%
src/mafw_tools/file_tools.py | save_to_pickle | 12 | 0 | 0 | 8 | 0 | 100%
src/mafw_tools/file_tools.py | load_from_pickle | 10 | 0 | 0 | 4 | 0 | 100%
src/mafw_tools/file_tools.py | generate_new_file_name | 15 | 0 | 0 | 12 | 0 | 100%
src/mafw_tools/file_tools.py | (no function) | 7 | 0 | 0 | 0 | 0 | 100%
src/mafw_tools/generic_tools.py | getattr_nested | 4 | 0 | 0 | 2 | 0 | 100%
src/mafw_tools/generic_tools.py | (no function) | 2 | 0 | 0 | 0 | 0 | 100%
src/mafw_tools/plotting_tools.py | plot_image | 21 | 0 | 0 | 10 | 0 | 100%
src/mafw_tools/plotting_tools.py | (no function) | 4 | 0 | 0 | 0 | 0 | 100%
Total |  | 75 | 0 | 0 | 36 | 0 | 100%

No items found using the specified filter.